/***************************************************************************
                          tqreceiversview.h  -  description
                             -------------------
    begin                : Tue Jan 11 2005
    copyright            : (C) 2005 by Richard Dale
    email                : Richard_Dale@tipitina.demon.co.uk
 ***************************************************************************/

/***************************************************************************
 *                                                                         *
 *   This program is free software; you can redistribute it and/or modify  *
 *   it under the terms of the GNU General Public License as published by  *
 *   the Free Software Foundation; either version 2 of the License, or     *
 *   (at your option) any later version.                                   *
 *                                                                         *
 ***************************************************************************/

#ifndef RECEIVERSVIEW_H
#define RECEIVERSVIEW_H

#include <tqwidget.h>
#include <klistview.h>

/**
  *@author Richard Dale
  */

class ReceiversView : public KListView  {
   Q_OBJECT
   TQ_OBJECT
public: 
   ReceiversView(TQWidget *parent=0, const char *name=0);
   ~ReceiversView();

  void buildList( TQObject *o );

public slots:
  void setTarget( TQObject * );
};

#endif
